pub struct Defaults {
pub base: Option<String>,
pub head: Option<String>,
pub scope: Option<Scope>,
pub fail_on: Option<FailOn>,
pub max_findings: Option<u32>,
pub diff_context: Option<u32>,
}Fields
base: Option<String>head: Option<String>scope: Option<Scope>fail_on: Option<FailOn>max_findings: Option<u32>diff_context: Option<u32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Defaults
impl<'de> Deserialize<'de> for Defaults
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Defaults
impl JsonSchema for Defaults
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for Defaults
impl StructuralPartialEq for Defaults