pub struct DirectoryOverrideConfig {
pub rules: Vec<RuleOverride>,
}Expand description
Per-directory override configuration (.diffguard.toml).
These files can be placed in any directory to override rule behavior for files in that directory and its subdirectories.
Fields
rules: Vec<RuleOverride>Rule-specific overrides.