pub struct Finding {
pub rule_id: String,
pub severity: Severity,
pub message: String,
pub path: String,
pub line: u32,
pub column: Option<u32>,
pub match_text: String,
pub snippet: String,
}Fields
rule_id: Stringseverity: Severitymessage: Stringpath: Stringline: u32column: Option<u32>match_text: Stringsnippet: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Finding
impl<'de> Deserialize<'de> for Finding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Finding
impl JsonSchema for Finding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for Finding
impl StructuralPartialEq for Finding